@@ -1,12 +1,10 @@
 `tdrocc` <-
 function(x, surv.time, surv.event, surv.entry=NULL, time, cutpts=NA, na.rm=FALSE, verbose=FALSE, span=0, lambda=0, ...) {
-
-	require(survivalROC)	
-	
+	#require(survivalROC)	
 	data <- list("x"=x, "surv.time"=surv.time, "surv.event"=surv.event)
 	cc.ix <- complete.cases(x, surv.time, surv.event, surv.entry)
    if (!all(cc.ix) && !na.rm) { stop("NA values are present!") }
-   if(verbose) { cat(sprintf("%i cases are removed due to NA values\n",as.integer(sum(!cc.ix)))) }
+   if(verbose) { message(sprintf("%i cases are removed due to NA values",as.integer(sum(!cc.ix)))) }
     
    x2 <- x[cc.ix]
    surv.time2 <- surv.time[cc.ix]
@@ -22,7 +20,7 @@ function(x, surv.time, surv.event, surv.entry=NULL, time, cutpts=NA, na.rm=FALSE
    
 	if(all(time < surv.time2[surv.event2 == 1])) { return(list("spec"=NA, "sens"=NA, "rule"=myrule, "cuts"=cutpts, "time"=time, "survival"=NA, "AUC"=NA, "data"=data)) }
     
-	rocco <- survivalROC(Stime=surv.time2, status=surv.event2, marker=x2, predict.time=time, cut.values=cutpts, entry=surv.entry, span=span, lambda=lambda, ...)
+	rocco <- survivalROC::survivalROC(Stime=surv.time2, status=surv.event2, marker=x2, predict.time=time, cut.values=cutpts, entry=surv.entry, span=span, lambda=lambda, ...)
 	res <- list("spec"=1-rocco$FP, "sens"=rocco$TP, "rule"=myrule, "cuts"=cutpts)
 	
 	return(list("spec"=1-rocco$FP, "sens"=rocco$TP, "rule"=myrule, "cuts"=cutpts, "time"=time, "survival"=rocco$Survival, "AUC"=rocco$AUC, "data"=data))
